@@ -1,6 +1,7 @@
 # system configuration generated and used by the sysconfig module
 build_time_vars = {'ABIFLAGS': '',
  'AC_APPLE_UNIVERSAL_BUILD': 0,
+ 'AIX_BUILDDATE': 0,
  'AIX_GENUINE_CPLUSPLUS': 0,
  'ALT_SOABI': 0,
  'ANDROID_API_LEVEL': 0,
@@ -10,10 +11,10 @@ build_time_vars = {'ABIFLAGS': '',
  'BASECPPFLAGS': '-IObjects -IInclude -IPython',
  'BASEMODLIBS': '',
  'BINDIR': '/usr/bin',
- 'BINLIBDEST': '/usr/lib/python3.8',
- 'BLDLIBRARY': '-lpython3.8',
+ 'BINLIBDEST': '/usr/lib/powerpc64le-linux-gnu/python3.9',
+ 'BLDLIBRARY': '-lpython3.9',
  'BLDSHARED': 'powerpc64le-linux-gnu-gcc -pthread -shared -Wl,-O1 '
-              '-Wl,-Bsymbolic-functions -Wl,-Bsymbolic-functions '
+              '-Wl,-Bsymbolic-functions -Wl,-Bsymbolic-functions  '
               ' -Wl,-z,relro -g '
               '-fwrapv -O2   ',
  'BUILDEXE': '',
@@ -23,7 +24,8 @@ build_time_vars = {'ABIFLAGS': '',
  'CC': 'powerpc64le-linux-gnu-gcc -pthread',
  'CCSHARED': '-fPIC',
  'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O2 -Wall -g '
-           ' '
+           '-ffile-prefix-map=/build/python3.9-LcLt5I/python3.9-3.9.5=. '
+           '  '
            ' -fstack-protector-strong '
            '-Wformat -Werror=format-security  -fexceptions  -g -fwrapv -O2 '
            '  ',
@@ -33,46 +35,53 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
  'CONFIGURE_CFLAGS': '-g '
-                     ' '
+                     '-ffile-prefix-map=/build/python3.9-LcLt5I/python3.9-3.9.5=. '
+                     '  '
                      ' '
                      '-fstack-protector-strong -Wformat -Werror=format-security  '
                      '-fexceptions',
  'CONFIGURE_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                             '-Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
-                            '-Werror=implicit-function-declaration',
+                            '-Werror=implicit-function-declaration '
+                            '-fvisibility=hidden',
  'CONFIGURE_CPPFLAGS': '-Wdate-time -D_FORTIFY_SOURCE=2',
- 'CONFIGURE_LDFLAGS': '-Wl,-Bsymbolic-functions '
+ 'CONFIGURE_LDFLAGS': '-Wl,-Bsymbolic-functions  '
                       ' -Wl,-z,relro '
                       '-g -fwrapv -O2   '
                       '',
  'CONFIGURE_LDFLAGS_NODIST': '',
- 'CONFIG_ARGS': "'--enable-shared' '--prefix=/usr' '--enable-ipv6' "
+ 'CONFIG_ARGS': "'--enable-shared' '--prefix=/usr' "
+                "'--libdir=/usr/lib/powerpc64le-linux-gnu' '--enable-ipv6' "
                 "'--enable-loadable-sqlite-extensions' "
                 "'--with-dbmliborder=bdb:gdbm' '--with-computed-gotos' "
                 "'--without-ensurepip' '--with-system-expat' '--with-dtrace' "
-                "'--with-system-ffi' 'CC=powerpc64le-linux-gnu-gcc' 'CFLAGS=-g "
-                ' '
+                "'--with-system-libmpdec' '--with-system-ffi' "
+                "'CC=powerpc64le-linux-gnu-gcc' 'CFLAGS=-g "
+                '-ffile-prefix-map=/build/python3.9-LcLt5I/python3.9-3.9.5=. '
+                '  '
                 ' -fstack-protector-strong '
                 "-Wformat -Werror=format-security  -fexceptions' "
-                "'LDFLAGS=-Wl,-Bsymbolic-functions "
+                "'LDFLAGS=-Wl,-Bsymbolic-functions  "
                 ' -Wl,-z,relro -g '
                 "-fwrapv -O2   ' "
                 "'CPPFLAGS=-Wdate-time -D_FORTIFY_SOURCE=2'",
  'CONFINCLUDEDIR': '/usr/include',
- 'CONFINCLUDEPY': '/usr/include/python3.8',
+ 'CONFINCLUDEPY': '/usr/include/python3.9',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/build/python3.8-3Yxoq1/python3.8-3.8.10/build-shared/coverage.info',
- 'COVERAGE_REPORT': '/build/python3.8-3Yxoq1/python3.8-3.8.10/build-shared/lcov-report',
+ 'COVERAGE_INFO': '/build/python3.9-LcLt5I/python3.9-3.9.5/build-shared/coverage.info',
+ 'COVERAGE_REPORT': '/build/python3.9-LcLt5I/python3.9-3.9.5/build-shared/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-IObjects -IInclude -IPython -I. -I../Include -Wdate-time '
              '-D_FORTIFY_SOURCE=2',
  'CXX': 'powerpc64le-linux-gnu-g++ -pthread',
- 'DESTDIRS': '/usr /usr/lib /usr/lib/python3.8 /usr/lib/python3.8/lib-dynload',
- 'DESTLIB': '/usr/lib/python3.8',
+ 'DESTDIRS': '/usr /usr/lib/powerpc64le-linux-gnu '
+             '/usr/lib/powerpc64le-linux-gnu/python3.9 '
+             '/usr/lib/python3.9/lib-dynload',
+ 'DESTLIB': '/usr/lib/python3.9',
  'DESTPATH': '',
- 'DESTSHARED': '/usr/lib/python3.8/lib-dynload',
+ 'DESTSHARED': '/usr/lib/python3.9/lib-dynload',
  'DFLAGS': '',
  'DIRMODE': 755,
  'DIST': 'README.rst ChangeLog configure configure.ac acconfig.h pyconfig.h.in '
@@ -94,13 +103,14 @@ build_time_vars = {'ABIFLAGS': '',
  'ENSUREPIP': 'no',
  'EXE': '',
  'EXEMODE': 755,
+ 'EXPORTSFROM': '',
+ 'EXPORTSYMS': '',
  'EXTRATESTOPTS': '',
- 'EXT_SUFFIX': '.cpython-38-powerpc64le-linux-gnu.so',
+ 'EXT_SUFFIX': '.cpython-39-powerpc64le-linux-gnu.so',
  'FILEMODE': 644,
  'FLOAT_WORDS_BIGENDIAN': 0,
  'FLOCK_NEEDS_LIBBSD': 0,
  'GETPGRP_HAVE_ARG': 0,
- 'GETTIMEOFDAY_NO_TZ': 0,
  'GITBRANCH': '',
  'GITTAG': '',
  'GITVERSION': '',
@@ -256,7 +266,6 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_GETSID': 1,
  'HAVE_GETSPENT': 1,
  'HAVE_GETSPNAM': 1,
- 'HAVE_GETTIMEOFDAY': 1,
  'HAVE_GETWD': 1,
  'HAVE_GLIBC_MEMMOVE_BUG': 0,
  'HAVE_GRP_H': 1,
@@ -292,14 +301,17 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_LINKAT': 1,
  'HAVE_LINUX_CAN_BCM_H': 1,
  'HAVE_LINUX_CAN_H': 1,
+ 'HAVE_LINUX_CAN_J1939_H': 1,
  'HAVE_LINUX_CAN_RAW_FD_FRAMES': 1,
  'HAVE_LINUX_CAN_RAW_H': 1,
+ 'HAVE_LINUX_CAN_RAW_JOIN_FILTERS': 1,
  'HAVE_LINUX_MEMFD_H': 1,
  'HAVE_LINUX_NETLINK_H': 1,
  'HAVE_LINUX_QRTR_H': 1,
  'HAVE_LINUX_RANDOM_H': 1,
  'HAVE_LINUX_TIPC_H': 1,
  'HAVE_LINUX_VM_SOCKETS_H': 1,
+ 'HAVE_LINUX_WAIT_H': 1,
  'HAVE_LOCKF': 1,
  'HAVE_LOG1P': 1,
  'HAVE_LOG2': 1,
@@ -351,7 +363,6 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_PTHREAD_KILL': 1,
  'HAVE_PTHREAD_SIGMASK': 1,
  'HAVE_PTY_H': 1,
- 'HAVE_PUTENV': 1,
  'HAVE_PWRITE': 1,
  'HAVE_PWRITEV': 1,
  'HAVE_PWRITEV2': 1,
@@ -503,7 +514,6 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_UNAME': 1,
  'HAVE_UNISTD_H': 1,
  'HAVE_UNLINKAT': 1,
- 'HAVE_UNSETENV': 1,
  'HAVE_USABLE_WCHAR_T': 0,
  'HAVE_UTIL_H': 0,
  'HAVE_UTIMENSAT': 1,
@@ -529,42 +539,42 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
  'HOST_GNU_TYPE': 'powerpc64le-unknown-linux-gnu',
- 'INCLDIRSTOMAKE': '/usr/include /usr/include /usr/include/python3.8 '
-                   '/usr/include/python3.8',
+ 'INCLDIRSTOMAKE': '/usr/include /usr/include /usr/include/python3.9 '
+                   '/usr/include/python3.9',
  'INCLUDEDIR': '/usr/include',
- 'INCLUDEPY': '/usr/include/python3.8',
+ 'INCLUDEPY': '/usr/include/python3.9',
  'INSTALL': '/usr/bin/install -c',
  'INSTALL_DATA': '/usr/bin/install -c -m 644',
  'INSTALL_PROGRAM': '/usr/bin/install -c',
  'INSTALL_SCRIPT': '/usr/bin/install -c',
  'INSTALL_SHARED': '/usr/bin/install -c -m 755',
- 'INSTSONAME': 'libpython3.8.so.1.0',
+ 'INSTSONAME': 'libpython3.9.so.1.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'powerpc64le-linux-gnu-g++ -pthread -shared -Wl,-O1 '
                 '-Wl,-Bsymbolic-functions',
  'LDFLAGS': '-Wl,-Bsymbolic-functions  '
-            '-Wl,-z,relro -g -fwrapv -O2   '
-            '',
+            ' -Wl,-z,relro -g -fwrapv '
+            '-O2   ',
  'LDFLAGS_NODIST': '',
- 'LDLIBRARY': 'libpython3.8.so',
+ 'LDLIBRARY': 'libpython3.9.so',
  'LDLIBRARYDIR': '',
  'LDSHARED': 'powerpc64le-linux-gnu-gcc -pthread -shared -Wl,-O1 '
-             '-Wl,-Bsymbolic-functions -Wl,-Bsymbolic-functions '
+             '-Wl,-Bsymbolic-functions -Wl,-Bsymbolic-functions  '
              ' -Wl,-z,relro -g -fwrapv '
              '-O2   ',
- 'LDVERSION': '3.8',
+ 'LDVERSION': '3.9',
  'LIBC': '',
- 'LIBDEST': '/usr/lib/python3.8',
- 'LIBDIR': '/usr/lib',
+ 'LIBDEST': '/usr/lib/python3.9',
+ 'LIBDIR': '/usr/lib/powerpc64le-linux-gnu',
  'LIBFFI_INCLUDEDIR': '',
  'LIBM': '-lm',
  'LIBOBJDIR': 'Python/',
  'LIBOBJS': '',
  'LIBPC': '/usr/lib/powerpc64le-linux-gnu/pkgconfig',
- 'LIBPL': '/usr/lib/python3.8/config-3.8-powerpc64le-linux-gnu',
+ 'LIBPL': '/usr/lib/python3.9/config-3.9-powerpc64le-linux-gnu',
  'LIBPYTHON': '',
- 'LIBRARY': 'libpython3.8.a',
+ 'LIBRARY': 'libpython3.9.a',
  'LIBRARY_OBJS': '\\',
  'LIBRARY_OBJS_OMIT_FROZEN': '\\',
  'LIBS': '-lcrypt -lpthread -ldl  -lutil -lm',
@@ -578,17 +588,17 @@ build_time_vars = {'ABIFLAGS': '',
  'LLVM_PROF_MERGER': 'true',
  'LN': 'ln',
  'LOCALMODLIBS': '-lexpat                       -L/usr/lib '
-                 '-lz                       -lexpat',
+                 '-lz                        -lexpat',
  'MACHDEP': 'linux',
  'MACHDEP_OBJS': '',
- 'MACHDESTLIB': '/usr/lib/python3.8',
+ 'MACHDESTLIB': '/usr/lib/powerpc64le-linux-gnu/python3.9',
  'MACOSX_DEPLOYMENT_TARGET': '',
  'MAINCC': 'powerpc64le-linux-gnu-gcc -pthread',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 1,
  'MAKESETUP': '../Modules/makesetup',
  'MANDIR': '/usr/share/man',
- 'MKDIR_P': '/bin/mkdir -p',
+ 'MKDIR_P': '/usr/bin/mkdir -p',
  'MODBUILT_NAMES': 'array  cmath  math  _struct  _random  _elementtree  '
                    '_pickle  _datetime  _bisect  _heapq  _statistics  '
                    'unicodedata  fcntl  spwd  grp  select  _csv  _socket  '
@@ -596,11 +606,11 @@ build_time_vars = {'ABIFLAGS': '',
                    '_blake2  syslog  binascii  zlib  posix  errno  pwd  _sre  '
                    '_codecs  _weakref  _functools  _operator  _collections  '
                    '_abc  itertools  atexit  _signal  _stat  time  _thread  '
-                   '_locale  _io  faulthandler  _tracemalloc  _symtable  '
-                   'pyexpat  xxsubtype',
+                   '_locale  _io  faulthandler  _tracemalloc  _peg_parser  '
+                   '_symtable  pyexpat  xxsubtype',
  'MODDISABLED_NAMES': '',
  'MODLIBS': '-lexpat                       -L/usr/lib '
-            '-lz                       -lexpat',
+            '-lz                        -lexpat',
  'MODOBJS': '$(sort   Modules/arraymodule.o  Modules/cmathmodule.o '
             'Modules/_math.o  Modules/mathmodule.o Modules/_math.o  '
             'Modules/_struct.o  Modules/_randommodule.o  '
@@ -626,7 +636,7 @@ build_time_vars = {'ABIFLAGS': '',
             'Modules/_iomodule.o Modules/iobase.o Modules/fileio.o '
             'Modules/bytesio.o Modules/bufferedio.o Modules/textio.o '
             'Modules/stringio.o  Modules/faulthandler.o  '
-            'Modules/_tracemalloc.o Modules/hashtable.o  '
+            'Modules/_tracemalloc.o  Modules/_peg_parser.o  '
             'Modules/symtablemodule.o  Modules/pyexpat.o  Modules/xxsubtype.o)',
  'MODULE_OBJS': '\\',
  'MULTIARCH': 'powerpc64le-linux-gnu',
@@ -646,9 +656,13 @@ build_time_vars = {'ABIFLAGS': '',
  'PACKAGE_URL': 0,
  'PACKAGE_VERSION': 0,
  'PARSER_HEADERS': '\\',
- 'PARSER_OBJS': '\\ Parser/myreadline.o Parser/parsetok.o Parser/tokenizer.o',
+ 'PARSER_OBJS': '\\ \\ Parser/myreadline.o Parser/parsetok.o '
+                'Parser/tokenizer.o',
+ 'PEGEN_HEADERS': '\\',
+ 'PEGEN_OBJS': '\\',
  'PGO_PROF_GEN_FLAG': '-fprofile-generate',
  'PGO_PROF_USE_FLAG': '',
+ 'PLATLIBDIR': 'lib',
  'POBJS': '\\',
  'POSIX_SEMAPHORES_NOT_ENABLED': 0,
  'PROFILE_TASK': '-m test --pgo',
@@ -664,12 +678,13 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHONFRAMEWORKPREFIX': '',
  'PYTHONPATH': '',
  'PYTHON_FOR_BUILD': './python -E',
- 'PYTHON_FOR_REGEN': 'python3.8',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
+ 'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha256,sha512,sha3,blake2"',
  'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g '
                              '-fwrapv -O2 -Wall -g '
-                             ' '
+                             '-ffile-prefix-map=/build/python3.9-LcLt5I/python3.9-3.9.5=. '
+                             '  '
                              ' '
                              '-fstack-protector-strong -Wformat '
                              '-Werror=format-security  -fexceptions  -g '
@@ -677,41 +692,42 @@ build_time_vars = {'ABIFLAGS': '',
                              ' -std=c99 -Wextra '
                              '-Wno-unused-result -Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
-                             '-Werror=implicit-function-declaration  '
-                             '-I../Include/internal -IObjects -IInclude '
-                             '-IPython -I. -I../Include -Wdate-time '
-                             '-D_FORTIFY_SOURCE=2 -fPIC '
+                             '-Werror=implicit-function-declaration '
+                             '-fvisibility=hidden  -I../Include/internal '
+                             '-IObjects -IInclude -IPython -I. -I../Include '
+                             '-Wdate-time -D_FORTIFY_SOURCE=2 -fPIC '
                              '-DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O2 -Wall '
-              '-g '
-              ' '
+              '-g -ffile-prefix-map=/build/python3.9-LcLt5I/python3.9-3.9.5=. '
+              '  '
               ' -fstack-protector-strong '
               '-Wformat -Werror=format-security  -fexceptions  -g -fwrapv -O2 '
               '  ',
  'PY_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
-                     '-Werror=implicit-function-declaration  '
-                     '-I../Include/internal',
+                     '-Werror=implicit-function-declaration '
+                     '-fvisibility=hidden  -I../Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O2 '
                    '-Wall -g '
-                   ' '
+                   '-ffile-prefix-map=/build/python3.9-LcLt5I/python3.9-3.9.5=. '
+                   '  '
                    ' '
                    '-fstack-protector-strong -Wformat -Werror=format-security  '
                    '-fexceptions  -g -fwrapv -O2   '
                    ' -std=c99 -Wextra -Wno-unused-result '
                    '-Wno-unused-parameter -Wno-missing-field-initializers '
-                   '-Werror=implicit-function-declaration  '
+                   '-Werror=implicit-function-declaration -fvisibility=hidden  '
                    '-I../Include/internal -IObjects -IInclude -IPython -I. '
                    '-I../Include -Wdate-time -D_FORTIFY_SOURCE=2 -fPIC '
                    '-DPy_BUILD_CORE',
- 'PY_CORE_LDFLAGS': '-Wl,-Bsymbolic-functions '
+ 'PY_CORE_LDFLAGS': '-Wl,-Bsymbolic-functions  '
                     ' -Wl,-z,relro -g '
                     '-fwrapv -O2   ',
  'PY_CPPFLAGS': '-IObjects -IInclude -IPython -I. -I../Include -Wdate-time '
                 '-D_FORTIFY_SOURCE=2',
  'PY_FORMAT_SIZE_T': '"z"',
- 'PY_LDFLAGS': '-Wl,-Bsymbolic-functions '
+ 'PY_LDFLAGS': '-Wl,-Bsymbolic-functions  '
                ' -Wl,-z,relro -g '
                '-fwrapv -O2   ',
  'PY_LDFLAGS_NODIST': '',
@@ -719,17 +735,18 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv '
                         '-O2 -Wall -g '
-                        ' '
+                        '-ffile-prefix-map=/build/python3.9-LcLt5I/python3.9-3.9.5=. '
+                        '  '
                         ' '
                         '-fstack-protector-strong -Wformat -Werror=format-security  '
                         '-fexceptions  -g -fwrapv -O2  '
                         '  -std=c99 '
                         '-Wextra -Wno-unused-result -Wno-unused-parameter '
                         '-Wno-missing-field-initializers '
-                        '-Werror=implicit-function-declaration  '
-                        '-I../Include/internal -IObjects -IInclude -IPython '
-                        '-I. -I../Include -Wdate-time -D_FORTIFY_SOURCE=2 '
-                        '-fPIC',
+                        '-Werror=implicit-function-declaration '
+                        '-fvisibility=hidden  -I../Include/internal -IObjects '
+                        '-IInclude -IPython -I. -I../Include -Wdate-time '
+                        '-D_FORTIFY_SOURCE=2 -fPIC',
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
  'Py_HASH_ALGORITHM': 0,
@@ -738,7 +755,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python3.8-3Yxoq1/python3.8-3.8.10/build-shared',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python3.9-LcLt5I/python3.9-3.9.5/build-shared',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SGI_ABI': '@SGI_ABI@',
@@ -766,8 +783,8 @@ build_time_vars = {'ABIFLAGS': '',
  'SIZEOF_VOID_P': 8,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
- 'SOABI': 'cpython-38-powerpc64le-linux-gnu',
- 'SRCDIRS': 'Parser Objects Python Modules Modules/_io Programs',
+ 'SOABI': 'cpython-39-powerpc64le-linux-gnu',
+ 'SRCDIRS': 'Parser Parser/pegen Objects Python Modules Modules/_io Programs',
  'SRC_GDB_HOOKS': '../Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
@@ -780,20 +797,21 @@ build_time_vars = {'ABIFLAGS': '',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python3.8-3Yxoq1/python3.8-3.8.10/build-shared '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python3.9-LcLt5I/python3.9-3.9.5/build-shared '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python3.8-3Yxoq1/python3.8-3.8.10/build-shared '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python3.9-LcLt5I/python3.9-3.9.5/build-shared '
                './python ../Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'TIMEMODULE_LIB': 0,
  'TIME_WITH_SYS_TIME': 1,
  'TM_IN_SYS_TIME': 0,
+ 'TZPATH': '/usr/share/zoneinfo:/usr/lib/zoneinfo:/usr/share/lib/zoneinfo:/etc/zoneinfo',
  'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
- 'UPDATE_FILE': 'python3.8 ../Tools/scripts/update_file.py',
+ 'UPDATE_FILE': 'python3.9 ../Tools/scripts/update_file.py',
  'USE_COMPUTED_GOTOS': 1,
- 'VERSION': '3.8',
+ 'VERSION': '3.9',
  'VPATH': '..',
  'WINDOW_HAS_FLAGS': 1,
  'WITH_DECIMAL_CONTEXTVAR': 1,
@@ -806,8 +824,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/build/python3.8-3Yxoq1/python3.8-3.8.10/build-shared',
- 'abs_srcdir': '/build/python3.8-3Yxoq1/python3.8-3.8.10/build-shared/..',
+ 'abs_builddir': '/build/python3.9-LcLt5I/python3.9-3.9.5/build-shared',
+ 'abs_srcdir': '/build/python3.9-LcLt5I/python3.9-3.9.5/build-shared/..',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
